package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcWljg;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcDbxtMapper;
import com.ruoyi.tcZz.domain.TcDbxt;
import com.ruoyi.tcZz.service.ITcDbxtService;

/**
 * 等保系统Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Service
public class TcDbxtServiceImpl implements ITcDbxtService 
{
    @Autowired
    private TcDbxtMapper tcDbxtMapper;

    /**
     * 查询等保系统
     * 
     * @param id 等保系统主键
     * @return 等保系统
     */
    @Override
    public TcDbxt selectTcDbxtById(Long id)
    {
        return tcDbxtMapper.selectTcDbxtById(id);
    }

    /**
     * 查询等保系统列表
     * 
     * @param tcDbxt 等保系统
     * @return 等保系统
     */
    @Override
    public List<TcDbxt> selectTcDbxtList(TcDbxt tcDbxt)
    {
        return tcDbxtMapper.selectTcDbxtList(tcDbxt);
    }

    /**
     * 新增等保系统
     * 
     * @param tcDbxt 等保系统
     * @return 结果
     */
    @Override
    public int insertTcDbxt(TcDbxt tcDbxt)
    {
        tcDbxt.setCreateTime(DateUtils.getNowDate());
        return tcDbxtMapper.insertTcDbxt(tcDbxt);
    }

    /**
     * 修改等保系统
     * 
     * @param tcDbxt 等保系统
     * @return 结果
     */
    @Override
    public int updateTcDbxt(TcDbxt tcDbxt)
    {
        tcDbxt.setUpdateTime(DateUtils.getNowDate());
        return tcDbxtMapper.updateTcDbxt(tcDbxt);
    }

    /**
     * 批量删除等保系统
     * 
     * @param ids 需要删除的等保系统主键
     * @return 结果
     */
    @Override
    public int deleteTcDbxtByIds(Long[] ids)
    {
        return tcDbxtMapper.deleteTcDbxtByIds(ids);
    }

    /**
     * 删除等保系统信息
     * 
     * @param id 等保系统主键
     * @return 结果
     */
    @Override
    public int deleteTcDbxtById(Long id)
    {
        return tcDbxtMapper.deleteTcDbxtById(id);
    }

    @Override
    public String importUser(List<TcDbxt> tcDbxtList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcDbxtList.isEmpty()) {
            for (TcDbxt tcDbxt : tcDbxtList) {
                tcDbxtMapper.insertTcDbxt(tcDbxt);
            }
            successMsg.append("导入成功");
        }

        return successMsg.toString();
    }

    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcDbxtMapper.updateByisStatus(isStatus,ids);
    }
}
