package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcDbdw;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcDbxt;
import com.ruoyi.tcZz.service.ITcDbxtService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 等保系统Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "等保系统")
@RequestMapping("/tcZz/networkSecurity/dbxt")
public class TcDbxtController extends BaseController {
    @Autowired
    private ITcDbxtService tcDbxtService;

    /**
     * 查询等保系统列表
     */
    @ApiOperation(value = "查询等保系统列表", response = TcDbxt.class)
    @GetMapping("/list")
    public TableDataInfo list(TcDbxt tcDbxt) {
        startPage();
        List<TcDbxt> list = tcDbxtService.selectTcDbxtList(tcDbxt);
        return getDataTable(list);
    }

    /**
     * 导出等保系统列表
     */
    @ApiOperation(value = "导出等保系统列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDbxt tcDbxt) {
        List<TcDbxt> list = tcDbxtService.selectTcDbxtList(tcDbxt);
        ExcelUtil<TcDbxt> util = new ExcelUtil<TcDbxt>(TcDbxt.class);
        util.exportExcel(response, list, "等保系统数据");
    }

    /**
     * 获取等保系统详细信息
     */
    @ApiOperation(value = "获取等保系统详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcDbxtService.selectTcDbxtById(id));
    }

    /**
     * 新增等保系统
     */
    @ApiOperation(value = "新增等保系统")
    @PostMapping
    public AjaxResult add(@RequestBody TcDbxt tcDbxt) {
        return toAjax(tcDbxtService.insertTcDbxt(tcDbxt));
    }

    /**
     * 修改等保系统
     */
    @ApiOperation(value = "修改等保系统")
    @PutMapping
    public AjaxResult edit(@RequestBody TcDbxt tcDbxt) {
        return toAjax(tcDbxtService.updateTcDbxt(tcDbxt));
    }

    /**
     * 删除等保系统
     */
    @ApiOperation(value = "删除等保系统")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcDbxtService.deleteTcDbxtByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcDbxt> util = new ExcelUtil<TcDbxt>(TcDbxt.class);
        List<TcDbxt> tcDbxtList = util.importExcel(file.getInputStream());
        tcDbxtService.importUser(tcDbxtList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcDbxtService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcDbxt> util = new ExcelUtil<TcDbxt>(TcDbxt.class);
        util.importTemplateExcel(response, " 等保系统");
    }
}
